@@ -19,18 +19,12 @@
   3. This notice may not be removed or altered from any source distribution.
 */
 
-/* Do our best to make sure va_copy is working */
-#if defined(__NGAGE__)
-#undef va_copy
-#define va_copy(dst, src) dst = src
-
-#elif defined(_MSC_VER) && _MSC_VER <= 1800
-/* Visual Studio 2013 tries to link with _vacopy in the C runtime. Newer versions do an inline assignment */
+// Do our best to make sure va_copy is working
+#if defined(_MSC_VER) && _MSC_VER <= 1800
+// Visual Studio 2013 tries to link with _vacopy in the C runtime. Newer versions do an inline assignment
 #undef va_copy
 #define va_copy(dst, src) dst = src
 
 #elif defined(__GNUC__) && (__GNUC__ < 3)
 #define va_copy(dst, src) __va_copy(dst, src)
 #endif
-
-/* vi: set ts=4 sw=4 expandtab: */
