@@ -19,15 +19,13 @@
   3. This notice may not be removed or altered from any source distribution.
 */
 
-#include "../../SDL_internal.h"
+#include "SDL_internal.h"
 
 #ifndef SDL_BCLIPBOARD_H
 #define SDL_BCLIPBOARD_H
 
-extern int HAIKU_SetClipboardText(_THIS, const char *text);
-extern char *HAIKU_GetClipboardText(_THIS);
-extern SDL_bool HAIKU_HasClipboardText(_THIS);
+extern bool HAIKU_SetClipboardText(SDL_VideoDevice *_this, const char *text);
+extern char *HAIKU_GetClipboardText(SDL_VideoDevice *_this);
+extern bool HAIKU_HasClipboardText(SDL_VideoDevice *_this);
 
 #endif
-
-/* vi: set ts=4 sw=4 expandtab: */
