@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -26,17 +26,15 @@
 extern "C" {
 #endif
 
-#include "../../main/haiku/SDL_BeApp.h"
+#include "../../core/haiku/SDL_BeApp.h"
 #include "../SDL_sysvideo.h"
 
-extern void HAIKU_VideoQuit(_THIS);
-extern int HAIKU_VideoInit(_THIS);
-extern void HAIKU_DeleteDevice(_THIS);
+extern void HAIKU_VideoQuit(SDL_VideoDevice *_this);
+extern bool HAIKU_VideoInit(SDL_VideoDevice *_this);
+extern void HAIKU_DeleteDevice(SDL_VideoDevice *_this);
 
 #ifdef __cplusplus
 }
 #endif
 
 #endif
-
-/* vi: set ts=4 sw=4 expandtab: */
